{ config, pkgs, lib, ... }:
let
    settings = import ./settings.nix;
in
{
    imports = [
        ./hardware-configuration.nix # Include the results of the hardware scan.
        ./core              # core system components
        ./system            # system components such as kernel
        ./nix-settings.nix  # nix related config
        ./users
        ./.luks-swap.nix
        ./fonts.nix         # system wide font settings
        ./extra             # extra packages
        ./dev               # development stuff
        ./games             # games
        ./hardware          # hardware specific settings
    ];

    # This value determines the NixOS release from which the default
    # settings for stateful data, like file locations and database versions
    # on your system were taken. It's perfectly fine and recommended to leave
    # this value at the release version of the first install of this system.
    # Before changing this value read the documentation for this option
    # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
    system.stateVersion = settings.stateVersion; # Did you read the comment?

    hardware.opengl.enable = true;

    # Set your time zone.
    time.timeZone = settings.system.timeZone;

    # Select internationalisation properties.
    i18n.defaultLocale = settings.system.defaultLocale;
    i18n.extraLocaleSettings = settings.system.extraLocales;

    # use bash shell for other users
    environment.shells = with pkgs; [ bash ];

    # Configure console keymap
    console.keyMap = settings.system.ttykeymap;

    environment.systemPackages = settings.system.pkgs;
}
