with import <nixpkgs> {};
{
    stateVersion = "23.11";

    system = {
        ttykeymap = "de";
        timeZone = "Europe/Berlin";
        defaultLocale = "en_US.UTF-8";
        extraLocales = {
            LC_ADDRESS = "de_DE.UTF-8";
            LC_IDENTIFICATION = "de_DE.UTF-8";
            LC_MEASUREMENT = "de_DE.UTF-8";
            LC_MONETARY = "de_DE.UTF-8";
            LC_NAME = "de_DE.UTF-8";
            LC_NUMERIC = "en_US.UTF-8";
            LC_PAPER = "de_DE.UTF-8";
            LC_TELEPHONE = "de_DE.UTF-8";
            LC_TIME = "de_DE.UTF-8";
        };

        pkgs = [
            ffmpeg-full
            openssl
            imagemagick
        ];
    };

    hardware = {
        # support for GPUs
        amdgpu = true;
        intelgpu = false;
        nvidiagpu = false;

        bluetooth = true;
        acpilight = false;
        iio = true;

        # support for yubikey and additional software
        yubikey = {
            enable = true;
            # additional software
            ykman = false;
            authenticator = true;   # flutter yubico authenticator
        };
    };

    fish = false;

    plasma5 = {
        enable = true;
        dconf = true;
        xwayland = true;
        excludePackages = with pkgs.libsForQt5; [
            elisa
            oxygen
            khelpcenter
            kcolorpicker
            konsole
        ];
    };

    virtualisation = {
        docker-rootless = {
            enable = true;
            autoPrune = true;
        };
        qemu = {
            enable = true;
            virt-manager = false;
        };
        waydroid = false;
        wine = {
            enable = true;
            wayland = false;
            winetricks = true;
        };
    };
    dev = {
        devbox = true;
        platformio = true;
        latex = true;
        dotnet = false;
        python3 = {
            enable = true;
            packages = ps: with ps; [
                pandas
                requests
                pygments
                tkinter
                numpy
                setuptools
                youtube-dl
                pip
                ipykernel
                scipy
            ];
        };
        arduino = {
            enable = false;  # enable arduino development platform
            ide2 = true;    # wether to use IDE 2.x or deprecated 1.x
        };
        android = {
            enable = true;
        };
        lsp = {
            enable = true;
            # various language server
            shellcheck = true;
            luals = true;
            pyright = true;
            arduino = true;
            clangd = true;
        };
    };

    dvd = true;     # enable DVD decryption + ripping via Handbrake
    bluray = true;  # enable Bluray decryption (requires additional setup)
    printing = {
        enable = true;
        avahi = true;
    };
    xdg = {
        enable = true;
        extraPortals = with pkgs; [
            xdg-desktop-portal-gtk
            xdg-desktop-portal-kde
        ];
    };
    java = true;
    dotnet = true;

    networking = {
        wireguard = true;   # enable wireguard protocol
        hostname = "servostar-nixos-flex";
    };

    games = {
        prismlauncher = true;
        steam = true;
    };

    sound = {
        pipewire = {
            enable = true;
            alsa = true;
            pulse = true;
            jack = true;
        };
        pulseaudio = {
            enable = false;
        };
    };
}
